# Extension

!!! tip
    Reference for the Python-Markdown extension can be found [here](https://python-markdown.github.io/extensions/).

::: rst_in_md.RestructuredTextInMarkdown

::: rst_in_md.RestructuredTextInMarkdownPreProcessor
